Constants
=========

.. currentmodule:: plutoprint

.. autodata:: __version__

.. autodata:: __version_info__

.. autodata:: __build_info__

.. autodata:: PLUTOBOOK_VERSION

.. autodata:: PLUTOBOOK_VERSION_MAJOR

.. autodata:: PLUTOBOOK_VERSION_MICRO

.. autodata:: PLUTOBOOK_VERSION_MINOR

.. autodata:: PLUTOBOOK_VERSION_STRING

.. autofunction:: plutobook_version

.. autofunction:: plutobook_version_string

.. autofunction:: plutobook_build_info

.. autodata:: MIN_PAGE_COUNT

.. autodata:: MAX_PAGE_COUNT

.. autodata:: UNITS_PT

.. autodata:: UNITS_PC

.. autodata:: UNITS_IN

.. autodata:: UNITS_CM

.. autodata:: UNITS_MM

.. autodata:: UNITS_PX
